@@ -36,12 +36,12 @@ from tripleo_common.tests.image import fakes
 
 filedata = six.u(
     """container_images:
-    - imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
+    - imagename: docker.io/tripleostein/heat-docker-agents-centos:latest
       push_destination: localhost:8787
-    - imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
+    - imagename: docker.io/tripleostein/centos-binary-nova-compute:liberty
       push_destination: localhost:8787
-    - imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
-    - imagename: docker.io/tripleomaster/image-with-missing-tag
+    - imagename: docker.io/tripleostein/centos-binary-nova-libvirt:liberty
+    - imagename: docker.io/tripleostein/image-with-missing-tag
       push_destination: localhost:8787
 """)
 
@@ -762,9 +762,12 @@ class TestBaseImageUploader(base.TestCase):
             ('localhost:8787/t/bink', [])
         )
         session = mock.Mock()
-        session.get.return_value.json.return_value = {
+        response = mock.Mock()
+        response.status_code = 200
+        response.json.return_value = {
             'repositories': ['t/foo', 't/bar', 't/baz', 't/bink']
         }
+        session.get.return_value = response
         self.assertEqual(
             [
                 'localhost:8787/t/foo:a',
@@ -783,6 +786,34 @@ class TestBaseImageUploader(base.TestCase):
                 (self.uploader, 'localhost:8787/t/bink', session)
             ])
 
+    @mock.patch('concurrent.futures.ThreadPoolExecutor')
+    def test_list_404(self, mock_pool):
+        # setup bits
+        session = mock.Mock()
+        response = mock.Mock()
+        response.status_code = 404
+        session.get.return_value = response
+        mock_pool.return_value.map.return_value = ()
+        # execute function
+        return_val = self.uploader.list('localhost:8787', session=session)
+        # check status of things
+        self.assertEqual(
+            [],
+            return_val
+        )
+
+    @mock.patch('concurrent.futures.ThreadPoolExecutor')
+    def test_list_500(self, mock_pool):
+        session = mock.Mock()
+        response = mock.Mock()
+        response.status_code = 500
+        session.get.return_value = response
+        mock_pool.return_value.map.return_value = ()
+        self.assertRaises(ImageUploaderException,
+                          self.uploader.list,
+                          'localhost:8787',
+                          session=session)
+
     def test_tags_for_image(self):
         session = mock.Mock()
         r = mock.Mock()
@@ -1137,10 +1168,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleostein/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleostein/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1156,9 +1187,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleomaster/'
+        source_url = urlparse('docker://docker.io/tripleostein/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleostein/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1229,10 +1260,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleostein/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleostein/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1248,9 +1279,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleomaster/'
+        source_url = urlparse('docker://docker.io/tripleostein/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleostein/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1295,10 +1326,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = '192.0.2.0:8787/tripleomaster/heat-docker-agents-centos'
+        image = '192.0.2.0:8787/tripleostein/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleostein/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1314,9 +1345,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://192.0.2.0:8787/tripleomaster/'
+        source_url = urlparse('docker://192.0.2.0:8787/tripleostein/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleostein/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1360,10 +1391,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleostein/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleostein/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1379,9 +1410,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleomaster/'
+        source_url = urlparse('docker://docker.io/tripleostein/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+        target_url = urlparse('docker://localhost:8787/tripleostein/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1458,11 +1489,11 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
+        image = 'docker.io/tripleostein/heat-docker-agents-centos'
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleostein/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1475,22 +1506,22 @@ class TestPythonImageUploader(base.TestCase):
         )
 
         source_url = urlparse(
-            'docker://docker.io/tripleomaster/'
+            'docker://docker.io/tripleostein/'
             'heat-docker-agents-centos:latest')
         unmodified_target_url = urlparse(
-            'docker://localhost:8787/tripleomaster/'
+            'docker://localhost:8787/tripleostein/'
             'heat-docker-agents-centos:latest')
         local_modified_url = urlparse(
-            'containers-storage:localhost:8787/tripleomaster/'
+            'containers-storage:localhost:8787/tripleostein/'
             'heat-docker-agents-centos:latestmodify-123')
         target_url = urlparse(
-            'docker://localhost:8787/tripleomaster/'
+            'docker://localhost:8787/tripleostein/'
             'heat-docker-agents-centos:latestmodify-123')
 
         self.assertEqual([
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleostein/'
             'heat-docker-agents-centos:latest',
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleostein/'
             'heat-docker-agents-centos:latestmodify-123'],
             self.uploader.upload_image(task)
         )
@@ -1544,9 +1575,9 @@ class TestPythonImageUploader(base.TestCase):
         run_modify_playbook.assert_called_once_with(
             'add-foo-plugin',
             {'foo_version': '1.0.1'},
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleostein/'
             'heat-docker-agents-centos:latest',
-            'localhost:8787/tripleomaster/'
+            'localhost:8787/tripleostein/'
             'heat-docker-agents-centos:latest',
             'modify-123',
             container_build_tool='buildah'
