@@ -40,20 +40,20 @@ kb.init_prepare_defaults(DEFAULTS_PATH)
 
 
 filedata = six.u("""container_images:
-- imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
+- imagename: docker.io/tripleostein/heat-docker-agents-centos:latest
   image_source: kolla
   push_destination: localhost:8787
-- imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
+- imagename: docker.io/tripleostein/centos-binary-nova-compute:liberty
   image_source: kolla
   uploader: docker
   push_destination: localhost:8787
-- imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
+- imagename: docker.io/tripleostein/centos-binary-nova-libvirt:liberty
   image_source: kolla
   uploader: docker
-- imagename: docker.io/tripleomaster/image-with-missing-tag
+- imagename: docker.io/tripleostein/image-with-missing-tag
   image_source: kolla
   push_destination: localhost:8787
-- imagename: docker.io/tripleomaster/skip-build
+- imagename: docker.io/tripleostein/skip-build
   image_source: foo
   push_destination: localhost:8787
 """)
@@ -234,10 +234,10 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': 'docker.io/tripleomaster',
+                'namespace': 'docker.io/tripleostein',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v3.2.1-stable-3.2-luminous-centos-7-x86_64',
+                'ceph_tag': 'v4.0.0-stable-4.0-nautilus-centos-7-x86_64',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
@@ -294,7 +294,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': '192.0.2.0:5000/tripleomaster',
+                'namespace': '192.0.2.0:5000/tripleostein',
                 'ceph_namespace': 'docker.io/cephh',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
@@ -360,7 +360,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_grafana_tag': 'v3.11',
             },
             builder.container_images_template_inputs(
-                namespace='192.0.2.0:5000/tripleomaster',
+                namespace='192.0.2.0:5000/tripleostein',
                 ceph_namespace='docker.io/cephh',
                 ceph_image='ceph-daemon',
                 ceph_tag='latest',
@@ -443,23 +443,23 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         )
         container_images = [{
             'image_source': 'kolla',
-            'imagename': 'docker.io/tripleomaster/'
+            'imagename': 'docker.io/tripleostein/'
                          'centos-binary-nova-compute:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
             'image_source': 'kolla',
-            'imagename': 'docker.io/tripleomaster/'
+            'imagename': 'docker.io/tripleostein/'
                          'centos-binary-nova-libvirt:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
             'image_source': 'kolla',
-            'imagename': 'docker.io/tripleomaster/image-with-missing-tag',
+            'imagename': 'docker.io/tripleostein/image-with-missing-tag',
             'push_destination': 'localhost:8787'
         }, {
             'image_source': 'foo',
-            'imagename': 'docker.io/tripleomaster/skip-build',
+            'imagename': 'docker.io/tripleostein/skip-build',
             'push_destination': 'localhost:8787'
         }]
         self.assertEqual(container_images, result)
@@ -502,28 +502,28 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync(self):
         remove_images = [
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-ovn-northd:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
                           'controller:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
@@ -532,25 +532,25 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-ovn-northd:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
                           'controller:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+             'imagename': 'docker.io/tripleostein/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='odl', remove_images=remove_images)
@@ -559,13 +559,13 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleomaster/centos-binary'
+             'imagename': 'docker.io/tripleostein/centos-binary'
                           '-opendaylight:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
